package cn.skcks.study.springcloud.kafka.tests;

import cn.skcks.study.springcloud.kafka.TestApplication;
import cn.skcks.study.springcloud.utils.JsonUtils;
import lombok.SneakyThrows;
import lombok.extern.slf4j.Slf4j;
import org.apache.kafka.clients.admin.AdminClient;
import org.apache.kafka.clients.admin.ListTopicsResult;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.kafka.KafkaProperties;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.context.ActiveProfiles;

import javax.annotation.PostConstruct;
import java.util.Map;

@ActiveProfiles("test")
@SpringBootTest(classes = TestApplication.class, webEnvironment = SpringBootTest.WebEnvironment.NONE)
@Slf4j
public class KafkaConfigTest {
    @Autowired
    private KafkaProperties kafkaProperties;

    private Map<String,Object> adminProperties;
    private Map<String,Object> producerProperties;
    private Map<String,Object> consumerProperties;
    private Map<String,Object> streamsProperties;

    @PostConstruct
    void init(){
        adminProperties = kafkaProperties.buildAdminProperties();
        producerProperties = kafkaProperties.buildProducerProperties();
        consumerProperties = kafkaProperties.buildConsumerProperties();
        streamsProperties = kafkaProperties.buildStreamsProperties();
    }

    @Test
    void properties () {
        log.info("AdminProperties {}", JsonUtils.toJson(adminProperties));
        log.info("ProducerProperties {}",JsonUtils.toJson(producerProperties));
        log.info("ConsumerProperties {}", JsonUtils.toJson(consumerProperties));
        log.info("StreamsProperties {}", JsonUtils.toJson(streamsProperties));
    }

    @Test
    @SneakyThrows
    void topics(){
        try (AdminClient adminClient = AdminClient.create(kafkaProperties.buildAdminProperties())) {
            ListTopicsResult topicsResult = adminClient.listTopics();
            topicsResult.listings().get().forEach(topic -> {
                log.info("topic uuid={} name={}",topic.topicId(),topic.name());
            });
        }
    }
}
